@@ -1,13 +1,11 @@
-package Exception::Routes;
-$Exception::Routes::VERSION = '0.007';
-use base qw(Exception);
-
 package QBit::WebInterface::Routing::Routes;
-$QBit::WebInterface::Routing::Routes::VERSION = '0.007';
+$QBit::WebInterface::Routing::Routes::VERSION = '0.008';
 use qbit;
 
 use base qw(QBit::Class);
 
+use Exception::Routes;
+
 use URI::Escape qw(uri_escape_utf8 uri_unescape);
 
 my %METHODS = (
